@@ -805,6 +805,84 @@ class SeqUtilsTest(unittest.TestCase):
         actual = seq(data)[item]
         self.assertEqual(actual.data, expect)
 
+    @ddt.data(
+        ([], 0),
+        ([0], 1),
+        ([1, 2, 3, 4, 5], 5),
+    )
+    @ddt.unpack
+    def test_seq_builtin_len(self, data, expect):
+        actual = len(seq(data))
+        self.assertEqual(actual, expect)
+
+    @ddt.data(
+        ([], 0, False),
+        ([0], 0, True),
+        ([0], -1, False),
+        ([1, 2, 3, 4, 5], 0, False),
+        ([1, 2, 3, 4, 5], 1, True),
+        ([1, 2, 3, 4, 5], -1, False),
+    )
+    @ddt.unpack
+    def test_seq_builtin_contains(self, data, item, expect):
+        actual = item in seq(data)
+        self.assertEqual(actual, expect)
+
+    @ddt.data(
+        ([], []),
+        ([0], [0]),
+        ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5]),
+    )
+    @ddt.unpack
+    def test_seq_builtin_iter(self, data, expect):
+        actual = list(x for x in seq(data))
+        self.assertEqual(actual, expect)
+
+    @ddt.data(
+        ([], []),
+        ([0], [0]),
+        ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1]),
+    )
+    @ddt.unpack
+    def test_seq_builtin_reversed(self, data, expect):
+        actual = list(x for x in reversed(seq(data)))
+        self.assertEqual(actual, expect)
+
+    @ddt.data(
+        ([], 0, 0),
+        ([0], 0, 1),
+        ([0], -1, 0),
+        ([0, 0, 0], 0, 3),
+        ([0, 0, 0], -1, 0),
+        ([1, 2, 3, 4, 5], 0, 0),
+        ([1, 2, 3, 4, 5], 1, 1),
+        ([1, 2, 3, 4, 5], -1, 0),
+    )
+    @ddt.unpack
+    def test_seq_count(self, data, item, expect):
+        actual = seq(data).count(item)
+        self.assertEqual(actual, expect)
+
+    @ddt.data(
+        ([], lambda x: True, 0),
+        ([0], lambda x: True, 1),
+        ([0], lambda x: False, 0),
+        ([0], lambda x: x % 2 == 0, 1),
+        ([0], lambda x: x % 2 == 1, 0),
+        ([0, 0, 0], lambda x: True, 3),
+        ([0, 0, 0], lambda x: False, 0),
+        ([0, 0, 0], lambda x: x % 2 == 0, 3),
+        ([0, 0, 0], lambda x: x % 2 == 1, 0),
+        ([1, 2, 3, 4, 5], lambda x: x % 2 == 0, 2),
+        ([1, 2, 3, 4, 5], lambda x: x % 2 == 1, 3),
+        ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 0, 6),
+        ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 1, 9),
+    )
+    @ddt.unpack
+    def test_seq_count_if(self, data, func, expect):
+        actual = seq(data).count_if(func)
+        self.assertEqual(actual, expect)
+
     @ddt.data(
         ([], 0, lambda x, y: x, []),
         ([], None, lambda x, y: x, []),
@@ -955,3 +1033,69 @@ class SeqUtilsTest(unittest.TestCase):
     def test_seq_flatten(self, data, expect):
         actual = seq(data).flatten()
         self.assertEqual(actual.data, expect)
+
+    @ddt.data(
+        ([], [], []),
+        ([0], [], []),
+        ([], [0], []),
+        ([0], [0], [(0, 0)]),
+        ([0, 0], [0], [(0, 0)]),
+        ([0], [0, 0], [(0, 0)]),
+        ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5], [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5)]),
+        ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1], [(1, 5), (2, 4), (3, 3), (4, 2), (5, 1)]),
+        ([1, 2, 3, 4, 5], ["a", "b", "c", "d", "e"], [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")]),
+        (["a", "b", "c", "d", "e"], [1, 2, 3, 4, 5], [("a", 1), ("b", 2), ("c", 3), ("d", 4), ("e", 5)]),
+    )
+    @ddt.unpack
+    def test_seq_zip(self, a, b, expect):
+        actual = seq(a).zip(seq(b))
+        self.assertEqual(actual.data, expect)
+
+    @ddt.data(
+        ([], [], 0, []),
+        ([0], [], None, [(0, None)]),
+        ([0], [], 1, [(0, 1)]),
+        ([], [0], None, [(None, 0)]),
+        ([], [0], 1, [(1, 0)]),
+        ([0], [0], 0, [(0, 0)]),
+        ([0, 0], [0], None, [(0, 0), (0, None)]),
+        ([0, 0], [0], 1, [(0, 0), (0, 1)]),
+        ([0], [0, 0], None, [(0, 0), (None, 0)]),
+        ([0], [0, 0], 1, [(0, 0), (1, 0)]),
+        ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5], None, [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5)]),
+        ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1], None, [(1, 5), (2, 4), (3, 3), (4, 2), (5, 1)]),
+        ([1, 2, 3, 4, 5, 6, 7], [1, 2, 3, 4, 5], 0, [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5), (6, 0), (7, 0)]),
+        ([1, 2, 3, 4, 5, 6, 7], [5, 4, 3, 2, 1], 0, [(1, 5), (2, 4), (3, 3), (4, 2), (5, 1), (6, 0), (7, 0)]),
+        ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5, 6, 7], 0, [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5), (0, 6), (0, 7)]),
+        ([1, 2, 3, 4, 5], [7, 6, 5, 4, 3, 2, 1], 0, [(1, 7), (2, 6), (3, 5), (4, 4), (5, 3), (0, 2), (0, 1)]),
+        ([1, 2, 3, 4, 5], ["a", "b", "c", "d", "e"], None, [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")]),
+        (["a", "b", "c", "d", "e"], [1, 2, 3, 4, 5], None, [("a", 1), ("b", 2), ("c", 3), ("d", 4), ("e", 5)]),
+        (
+            [1, 2, 3, 4, 5],
+            ["a", "b", "c", "d", "e", "f", "g"],
+            0,
+            [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e"), (0, "f"), (0, "g")],
+        ),
+        (
+            [1, 2, 3, 4, 5],
+            ["a", "b", "c", "d", "e", "f", "g"],
+            "-",
+            [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e"), ("-", "f"), ("-", "g")],
+        ),
+        (
+            [1, 2, 3, 4, 5, 6, 7],
+            ["a", "b", "c", "d", "e"],
+            "-",
+            [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e"), (6, "-"), (7, "-")],
+        ),
+        (
+            [1, 2, 3, 4, 5, 6, 7],
+            ["a", "b", "c", "d", "e"],
+            0,
+            [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e"), (6, 0), (7, 0)],
+        ),
+    )
+    @ddt.unpack
+    def test_seq_zip_fill(self, a, b, fill, expect):
+        actual = seq(a).zip_fill(seq(b), fill)
+        self.assertEqual(actual.data, expect)
